==> Paws-0.25.tar.gz: Paws-0.25/lib/Paws/ApiGateway/DeleteAuthorizer.pm <==

package Paws::ApiGateway::DeleteAuthorizer;
  use Moose;
  has AuthorizerId => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'authorizerId' , required => 1);
  has RestApiId => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'restApiId' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteAuthorizer');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/restapis/{restapi_id}/authorizers/{authorizer_id}');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'DELETE');
  class_has _returns => (isa => 'Str', is => 'ro');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::ApiGateway::DeleteAuthorizer - Arguments for method DeleteAuthorizer on Paws::ApiGateway

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteAuthorizer on the 
Amazon API Gateway service. Use the attributes of this class
as arguments to method DeleteAuthorizer.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteAuthorizer.

As an example:

  $service_obj->DeleteAuthorizer(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> AuthorizerId => Str

The identifier of the Authorizer resource.



=head2 B<REQUIRED> RestApiId => Str

The RestApi identifier for the Authorizer resource.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteAuthorizer in L<Paws::ApiGateway>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.33.tar.gz: Paws-0.33/lib/Paws/ApiGateway/DeleteAuthorizer.pm <==

package Paws::ApiGateway::DeleteAuthorizer;
  use Moose;
  has AuthorizerId => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'authorizerId' , required => 1);
  has RestApiId => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'restApiId' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteAuthorizer');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/restapis/{restapi_id}/authorizers/{authorizer_id}');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'DELETE');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::API::Response');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::ApiGateway::DeleteAuthorizer - Arguments for method DeleteAuthorizer on Paws::ApiGateway

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteAuthorizer on the 
Amazon API Gateway service. Use the attributes of this class
as arguments to method DeleteAuthorizer.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteAuthorizer.

As an example:

  $service_obj->DeleteAuthorizer(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> AuthorizerId => Str

The identifier of the Authorizer resource.



=head2 B<REQUIRED> RestApiId => Str

The RestApi identifier for the Authorizer resource.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteAuthorizer in L<Paws::ApiGateway>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
